
# Slot: causes


holds between two entities where the occurrence, existence, or activity of one causes the occurrence or generation of the other

URI: [biolink:causes](https://w3id.org/biolink/vocab/causes)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [contributes to](contributes_to.md)

## Children

 *  [causes adverse event](causes_adverse_event.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0002506 |
|  | | SEMMEDDB:CAUSES |
|  | | SEMMEDDB:causes |
|  | | WIKIDATA_PROPERTY:P1542 |
|  | | SNOMED:cause_of |
| **Narrow Mappings:** | | MONDO:disease_triggers |
|  | | GOREL:0000040 |
|  | | MONDO:disease_causes_feature |
|  | | MONDO:disease_triggers |
|  | | NCIT:allele_has_abnormality |
|  | | NCIT:biological_process_has_result_biological_process |
|  | | NCIT:chemical_or_drug_has_physiologic_effect |
|  | | NCIT:chemical_or_drug_initiates_biological_process |
|  | | NCIT:process_initiates_biological_process |
|  | | NCIT:chromosome_mapped_to_disease |
|  | | NCIT:disease_has_normal_tissue_origin |
|  | | OBO:nbo#in_response_to |
|  | | ORPHA:317343 |
|  | | ORPHA:317344 |
|  | | ORPHA:317346 |
|  | | ORPHA:410295 |
|  | | ORPHA:410296 |
|  | | RO:0002256 |
|  | | RO:0002315 |
|  | | RO:0002507 |
|  | | RO:0002509 |
|  | | RO:0004001 |
|  | | RTXKG1:capable_of_part_of |
|  | | SNOMED:causative_agent_of |
|  | | SNOMED:has_realization |
|  | | UMLS:has_physiologic_effect |
| **Broad Mappings:** | | RO:0002410 |

